# Data Inspector Library Examples

This package contains examples for the Data Inspector Library.

## Prerequisites

To build and run the Data Inspector Library examples, you need the following:

- [Repository credentials](#repository-credentials)
- [Platform credentials](#platform-credentials)
- [Node.js](https://nodejs.org/) version 10.14.0 or higher (the latest stable version is recommended)
- [npm](https://www.npmjs.com/) package manager (shipped along with Node.js and needed to run
the commands in this guide)
- WebGL-enabled browser to be able to see visualizations. The latest versions of Google Chrome,
Mozilla Firefox, and Apple Safari all support this technology. To test if your browser supports
WebGL, visit <https://get.webgl.org/>.

## Authentication and Authorization

Before getting started, you need to obtain *repository* and *platform* credentials from the HERE
platform.

### Repository Credentials

You need these credentials to access the HERE Artifactory Repository that serves the Data Inspector
Library projects from a private npm registry.

Repository credentials are stored in a Maven `settings.xml` file generated and downloaded from the
HERE platform. The `username` and `password` tags in this file contain your credentials to the HERE
Artifactory Repository.

For more information on how to get credentials, see the
[Teams and Permissions User Guide](https://developer.here.com/olp/documentation/access-control/user-guide/topics/get-credentials.html).

### Platform Credentials

The Data Inspector Library examples need these credentials to authenticate with the HERE platform
and access data in catalogs and layers stored on the platform.

Platform credentials are the `here.access.key.id` and `here.access.key.secret` from the
`credentials.properties` file downloaded from the platform.

For more information on how to get credentials, see the
[Teams and Permissions User Guide](https://developer.here.com/olp/documentation/access-control/user-guide/topics/get-credentials.html).

## Use Your Repository Credentials

1. To access the Data Inspector Library from the HERE Artifactory Repository, you first need to
obtain the corresponding credentials from the [platform](https://platform.here.com/) by going to
__Account__ > __Repository__ or by following the link below:

  - For users from China: <https://platform.hereolp.cn/profile/repository>
  - For users from other regions: <https://platform.here.com/profile/repository>

2. Click __Create credentials__. In the frame that appears, the Maven `settings.xml` file is
generated. This file contains your repository credentials in the `username` and `password` tags. You
can use these credentials by copying them either from the frame or from the downloaded
`settings.xml`.

3. The next step is to change the default npm registry and then log into the HERE Artifactory
Repository using the following commands:

  - For users from China:

    ```shell
    npm config set @here:registry https://repo.platform.hereolp.cn/artifactory/api/npm/here-node/
    ```

    and

    ```shell
    npm login --registry=https://repo.platform.hereolp.cn/artifactory/api/npm/here-node/ --scope=@here
    ```

  - For users from other regions:

    ```shell
    npm config set @here:registry https://repo.platform.here.com/artifactory/api/npm/here-node/
    ```

    and

    ```shell
    npm login --registry=https://repo.platform.here.com/artifactory/api/npm/here-node/ --scope=@here
    ```

4. Enter the username and password that you got from the `settings.xml` as well as your email
address.

  > #### Note::No visual feedback for passwords
  > The command-line interface might not provide any visual feedback while you're entering your
  > password. For example, you can't see placeholder characters when typing your password, and the
  > cursor might stay in the same position.

### Set Up npm to Work through Proxy

In case you need to get npm to work through a proxy, set `proxy` and `https-proxy` settings with the
following commands while replacing the URL `http://proxy.company.com:8080` with the URL of your
proxy server:

```shell
npm config set proxy http://proxy.company.com:8080
```

and

```shell
npm config set https-proxy http://proxy.company.com:8080
```

> #### Note::Use a credentials pair in double quotes for authenticated proxy servers
> In case you use an authenticated proxy, the URL must contain a `Username:Password` pair. If you
> have special characters in your password, enclose the `Username:Password` pair in double quotes
> as shown below:
>
> ```shell
> npm config set proxy http://"Username:Password"@proxy.company.com:8080
>```
>
> and
>
> ```shell
> npm config set https-proxy http://"Username:Password"@proxy.company.com:8080
> ```

Once you have access to the HERE Artifactory Repository, find the projects for the Data Inspector
Library under the `@here` namespace.

## Use Platform Credentials

1. To get your platform credentials, you need to register your application on the [platform](https://platform.here.com/)
by going to __Launcher__ > __Access Manager__ > __Apps__ or by following the link below:

  - For users from China: https://platform.hereolp.cn/admin/apps
  - For users from other regions: https://platform.here.com/admin/apps

2. From there, click __Register new app__ and provide the requested information.

3. Click the __Register__ button. The platform registers a new application with a unique ID.

4. Now create credentials for your application by clicking __Create credentials__. You can only
create two keys per application.

5. After you have created credentials, you're prompted to download the `credentials.properties`
file, which contains an access key ID and an access key secret that are unique to your application.

  > #### Note::One-time download of credentials
  > You can download the credentials file or copy your access key ID and access key secret only
  > once, when created, so make sure to store it safely. After you close the dialog, you can't
  > retrieve your key secret. However, you can retrieve your key ID later or you can get a new ID
  > and secret any time.

6. After you have obtained credentials, use them to authenticate with the platform. You have two
options for authentication:

  - [Enter your credentials into the authentication form](#enter-credentials)
  - [Use your local authentication file](use-local-authentication-file)

  and a feature for reconnection:

  - [Auto connect](#auto-connect).

### Enter Credentials

Enter your access key ID and access key secret from the `credentials.properties` file into the
authentication form in the Data Inspector window when running Data Inspector Library example
applications. This way, the application automatically generates an access token for you. Once the
token has expired, the application automatically requests a new one.

Additionally, if you want your application to access catalog data from within a specific project,
you can enter the HERE Resource Name (HRN) of that project. Get the project HRN you need from the
[platform](https://platform.here.com/) by going to __Launcher__ > __Projects Manager__.

> #### Note::Get access permissions from catalog owners
> To work with catalogs and layers, your application needs access permissions that are granted by
> catalog owners. For more information, see the
> [Teams and Permissions User Guide](https://developer.here.com/olp/documentation/access-control/user-guide/index.html).

### Use Local Authentication File

Similar to the previous option, you can use your access key ID and access key secret but store them
in a `config.json` file. This way, you don't have to enter the credentials into the authentication
form.

You can find an example of this file called `config.json.example` in the root folder of Data
Inspector Library example applications. Save a copy of this file as `config.json`, remove the
commented header, and replace the placeholder values with your credentials.

> #### Note::Do not share your local authentication file
> This authentication option should be used for local development only. If you plan to host your
> application somewhere or share access to it with other users, make sure to remove the
> `config.json` file from your application's folder. Otherwise, your access credentials will be
> visible to anyone who has access to your application.

### Auto Connect

This feature is available for both authentication options. It allows you to persist the connection
to the platform.

Once you establish a connection, toggle this switch on so that your application automatically
reconnects whenever you refresh the browser window. The application reuses the credentials of the
first successful connection.

However, this feature is disabled after you end your session by closing the tab in your browser
window.

## Install Example Applications

1. To obtain the latest version of Data Inspector Library examples and run them, create an empty
directory and run the following command in it:

  - For users from China:

    ```shell
    npx @here/olp-examples --china
    ```

  - For users from other regions:

    ```shell
    npx @here/olp-examples
    ```

  Alternatively, you can [download an archive with Data Inspector examples](https://platform.here.com/data-inspector/data-inspector-examples-latest.zip)
  from the platform. When done, you can run the following command in the extracted archive folder:

  - For users from China:

    ```shell
    npm install && node ./olp-examples --china
    ```

  - For users from other regions:

    ```shell
    npm install && node ./olp-examples
    ```

2. Once the server is running, open <http://localhost:5000/> in your favorite browser. The HTTP
server application automatically copies this URL to the clipboard, so you can just paste it into
your browser.

3. When running the examples, use the __Source code__ button to show the source code.
