/*
 * Copyright (C) 2017-2024 HERE Global B.V. and its affiliate(s). All rights reserved.
 *
 * This software and other materials contain proprietary information controlled by HERE and are
 * protected by applicable copyright legislation. Any use and utilization of this software and other
 * materials and disclosure to any third parties is conditional upon having a separate agreement
 * with HERE for the access, use, utilization or disclosure of this software. In the absence of such
 * agreement, the use of the software is not allowed.
 */

/** @module @here/olp-examples **//***/

import { WorkerServiceManager } from "@here/harp-mapview-decoder/index-worker";
import {
    DecodedInteractiveTile,
    DecoderService,
    InteractiveTileDecoder
} from "@here/interactive-datasource-protocol";

/**
 * `SpeedLimitsTileDecoder` returns an instance of `DecodedSpeedLimitsTile` with speed limits data.
 * No actual geometry is created here because speed limits data has no geometry information - it is
 * mapped to road segments.
 */
export class SpeedLimitsTileDecoder extends InteractiveTileDecoder {
    /** @inheritdoc */
    protected async createGeometries(): Promise<DecodedInteractiveTile> {
        return {
            geometries: [],
            techniques: []
        };
    }
}

/**
 * Register[[SpeedLimitsTileDecoder]] service class in [[WorkerServiceManager]].
 *
 * Has to be called during initialization of decoder bundle.
 */
export function registerSpeedLimitsWorker(name = "speedlimits") {
    WorkerServiceManager.getInstance().register({
        serviceType: name,
        factory: (serviceId: string) => new DecoderService(serviceId, new SpeedLimitsTileDecoder())
    });
}
