/*
 * Copyright (C) 2017-2024 HERE Global B.V. and its affiliate(s). All rights reserved.
 *
 * This software and other materials contain proprietary information controlled by HERE and are
 * protected by applicable copyright legislation. Any use and utilization of this software and other
 * materials and disclosure to any third parties is conditional upon having a separate agreement
 * with HERE for the access, use, utilization or disclosure of this software. In the absence of such
 * agreement, the use of the software is not allowed.
 */

import { Theme } from "@here/harp-datasource-protocol";

/** @module @here/olp-examples **//***/

// snippet:speedlimits_theme.ts
// Common styles for speed limit line.
const lineAttributes = {
    lineWidth: "4px",
    clipping: false // Line will not be clipped by tile bounds
};

/** Theme for visualization of speed limits geometries. */
export const SpeedLimitTheme: Theme = {
    styles: {
        speedlimits: [
            {
                technique: "solid-line",
                description: "Style for visualizing low speed limits.",
                when: ["==", ["get", "type"], "speedlimit-line-low"],
                renderOrder: 10010,
                color: "rgb(191,33,47)",
                ...lineAttributes
            },
            {
                technique: "solid-line",
                description: "Style for visualizing medium speed limits.",
                when: ["==", ["get", "type"], "speedlimit-line-medium"],
                renderOrder: 10009,
                color: "rgb(249,167,62)",
                ...lineAttributes
            },
            {
                technique: "solid-line",
                description: "Style for visualizing high speed limits.",
                when: ["==", ["get", "type"], "speedlimit-line-high"],
                renderOrder: 10008,
                color: "rgb(39,179,118)",
                ...lineAttributes
            }
        ]
    }
};
// end:speedlimits_theme.ts
