/*
 * Copyright (C) 2018-2024 HERE Global B.V. and its affiliate(s). All rights reserved.
 *
 * This software and other materials contain proprietary information controlled by HERE and are
 * protected by applicable copyright legislation. Any use and utilization of this software and other
 * materials and disclosure to any third parties is conditional upon having a separate agreement
 * with HERE for the access, use, utilization or disclosure of this software. In the absence of such
 * agreement, the use of the software is not allowed.
 */

import { InteractiveIntersectionAgent } from "@here/interactive-datasource-protocol";
import { DataInspector, GeoJsonInfoPanel, installInfoWidgets } from "@here/interactive-mapview-ui";
import { GeoJsonDataSource } from "@here/olp-geojson-datasource";
import {
    useToken,
    locale,
    omvDataLayer,
    omvHostHrn,
    lookupServiceEnvironment,
    geoJsonProperties
} from "../config";
import { bearerTokenProvider } from "./common";


const dataInspector = new DataInspector(
    {
        mapView: {
            theme: "../resources/normal.grey.day.json",
            decoder: { url: "../decoder.bundle.js" },
            defaultZoomLevel: 16.5,
            enableRotation: true,
            enableTilt: true,
            enableExtrudedBuildings: true,
            geoCenter: {
                latitude: 52.51650,
                longitude: 13.38183
            }
        },
        monacoEditorWorkersBasePath: "../monaco-editor",
        translationsBasePath: "../resources/i18n/",
        streamSaverBasePath: "../resources/mitm/",
        defaultLocale: locale || undefined,
        baseMap: {
            hrn: omvHostHrn,
            layer: omvDataLayer
        },
        getBearerToken: useToken ? bearerTokenProvider : undefined,
        widgets: {
            authForm: !useToken ? {
                tokenForm: false,
                accessKeyForm: true,
                localAuthForm: true
            } : undefined,
            decodedPanel: { enabled: false }
        },
        toolbar: {
            languageSelector: true
        },
        lookupServiceEnvironment,
        enable3DRendering: true,
        pageUrlParams: { enabled: true }
    },
    document.getElementById("map-here") as HTMLElement,
    {},
    true,
    {
        "event-data-inspector-is-ready": renderGeoJson,
        "aftermount": addDataSource
    }
);

function renderGeoJson() {
    const { interactiveDataSource } = dataInspector;
    if (interactiveDataSource instanceof GeoJsonDataSource) {
        interactiveDataSource.renderGeoJson(geoJsonProperties);
    }
}

async function addDataSource() {
    if (dataInspector.mapView === undefined) {
        return;
    }
    const geoJsonDataSource = new GeoJsonDataSource({
        intersectionAgent: new InteractiveIntersectionAgent(dataInspector.mapView, false)
    });
    geoJsonDataSource.isSelected = true;
    await geoJsonDataSource.connect();
    await dataInspector.setInteractiveDataSources([geoJsonDataSource]);

    installInfoWidgets(GeoJsonInfoPanel, geoJsonDataSource, document.body, "geojson-info-panel", true, 0);
}
