/*
 * Copyright (C) 2018-2024 HERE Global B.V. and its affiliate(s). All rights reserved.
 *
 * This software and other materials contain proprietary information controlled by HERE and are
 * protected by applicable copyright legislation. Any use and utilization of this software and other
 * materials and disclosure to any third parties is conditional upon having a separate agreement
 * with HERE for the access, use, utilization or disclosure of this software. In the absence of such
 * agreement, the use of the software is not allowed.
 */

/*
 * This file shows the simple client application, that uses token provider instead of the
 * authentication form.
 */

import { DataInspector } from "@here/interactive-mapview-ui";

// snippet:token-provider-getBearerToken.js
/** Time to live of the token, in seconds. */
const TTL = 3600;

async function getBearerToken() {
    const response = await fetch(`http://localhost:3000/getToken?ttl=${TTL}`);

    if (!response.ok) {
        throw new Error(response.statusText);
    }

    return response.text();
}
// end:token-provider-getBearerToken.js

const dataInspector = new DataInspector(
    {
        getBearerToken,
        mapView: {
            theme: "https://platform.here.com/data-inspector/resources/normal.reduced.night.json",
            decoder: {
                url: "./client/decoder.bundle.js"
            }
        }
    },
    document.getElementById("map-here"),
    {
        interactiveDataSource: {
            hrn: "hrn:here:data::olp-here:rib-2",
            layer: "topology-geometry"
        },
        enableCoverage: true
    }
);
dataInspector.toggleFullscreen(true);
