const { merge } = require("webpack-merge");
const path = require("path");

const commonConfig = {
    mode: "development",
    context: __dirname,
    devtool: "source-map",
    module: {
        rules: [
            { test: /\.css$/, use: ["style-loader", "css-loader"] },
            { test: /\.scss$/, use: ["style-loader", "css-loader", "sass-loader"] },
            { test: /\.(png|jpg|gif|svg|woff|woff2|eot)$/, loader: "url-loader?limit=100000" },
            {
                test: /\.ttf$/,
                use: [{
                    loader: "file-loader",
                    options: {
                        name: "[name].[ext]",
                        outputPath: "dist/monaco-editor"
                    }
                }]
            }
        ]
    }
};

const decoderConfig = merge(commonConfig, {
    target: "webworker",
    entry: "./client/decoder.js",
    output: {
        filename: "client/decoder.bundle.js"
    },
});

const browserConfig = merge(commonConfig, {
    entry: "./client/app.js",
    output: {
        filename: "client/app.bundle.js"
    },
    devServer: {
        webSocketServer: 'sockjs',
        host: "0.0.0.0",
        allowedHosts: 'all',
        static: {
            directory: __dirname,
        }
    }
});

const monacoWorkersConfig = merge(commonConfig, {
    target: "webworker",
    entry: {
        "editor.worker": "monaco-editor/esm/vs/editor/editor.worker.js",
        "ts.worker": "monaco-editor/esm/vs/language/typescript/ts.worker"
    },
    output: {
        filename: "monaco-editor/[name].bundle.js"
    }
});


module.exports = [monacoWorkersConfig, decoderConfig, browserConfig];
